==> vows-is-0.1.16.tgz: package/test/vows-is-test.js <==
var is = require("../src/vows-is.js");

is.config(require("./config.js"));

is.partial("GET", function _partial(context) {
	return context
		.vow.it.should.not.error
		.vow.it.should.have.status(200)
		.vow.it.should.have.header("content-type", "text/html; charset=utf-8")

		.context("contains a body that")
			.topic.is.property('body')
			.vow.it.should.be.ok
			.vow.it.should.include.string("hello world")
});

var suite = is.suite("vows-is").batch()

	.context("a request to GET /")
		.topic.is.a.request("GET /")
		.partial("GET")		

.batch()

	.context("2 into 6")
		.topic.is(function() { return 6 / 2; })
		.vow.it.should.be.a("number")
		.vow.it.should.eql(3)
		.parent()

	.context("123")
		.topic.is(123)
		.vow.it.should.be.a("number")
		.vow.it.should.eql(123)
		.context("divided by 10")
			.topic.is(function(topic) { return topic / 10 })
			.vow.it.should.eql(12.3)
			.batch()

	.context("1 plus 3")
		.topic.is(function() { return 1 + 3; })
		.vow.it.should.be.a("number")
		.vow.it.should.eql(4)
		.context("subtract 5")
			.topic.is(function(topic) { return topic - 5; })
			.vow.it.should.be.a("number")
			.vow.it.should.eql(-1)
			.context("times 2")
				.topic.is(function(topic) { return topic * 2; })
				.vow.it.should.be.a("number")
				.vow.it.should.eql(-2)
				.parent()
			.context("times 0")
				.topic.is(function (topic) { return topic * 0; })
				.vow.it.should.eql(0)
				
.suite();

if (module.parent) {
	suite["export"](module);
} else {
	suite.run({
		reporter: is.reporter
	}, function() {
		is.end();	
	});
}

==> vows-is-0.1.34.tgz: package/test/vows-is-test.js <==
var is = require("../src/vows-is.js");

is.config(require("./config.js"));

is.partial("req", function _partial(context, header) {
	return context
		.vow.it.should.not.error
		.vow.it.should.have.status(200)
		.vow.it.should.have.header("content-type", header || "text/html; charset=utf-8");
});

is.partial("GET", function _partial(context) {
	return context
		.partial("req")
		.context("contains a body that")
			.topic.is.property('body')
			.vow.it.should.be.ok
			.vow.it.should.include.string("hello world")
});

var suite = is.suite("vows-is").batch()

	.context("a request to GET /")
		.topic.is.a.request("GET /")
		.partial("GET")
		.batch()
	.context("an echo request to POST /echo")
		.topic.is.a.request({
			"uri": "http://localhost:4000/echo",
			"method": "POST",
			"json": {
				"foo": "bar"
			}
		})
		.partial("req", "application/json; charset=utf-8")
		.context("contains a body that")
			.topic.is.property("body")
			.vow.it.should.be.ok
			.vow.it.should.have.property("foo").and.be.equal("bar")

.batch()

	.context("2 into 6")
		.topic.is(function() { return 6 / 2; })
		.vow.it.should.be.a("number")
		.vow.it.should.eql(3)
		.parent()

	.context("123")
		.topic.is(123)
		.vow.it.should.be.a("number")
		.vow.it.should.eql(123)
		.context("divided by 10")
			.topic.is(function(topic) { return topic / 10 })
			.vow.it.should.eql(12.3)
			.batch()

	.context("1 plus 3")
		.topic.is(function() { return 1 + 3; })
		.vow.it.should.be.a("number")
		.vow.it.should.eql(4)
		.context("subtract 5")
			.topic.is(function(topic) { return topic - 5; })
			.vow.it.should.be.a("number")
			.vow.it.should.eql(-1)
			.context("times 2")
				.topic.is(function(topic) { return topic * 2; })
				.vow.it.should.be.a("number")
				.vow.it.should.eql(-2)
				.parent()
			.context("times 0")
				.topic.is(function (topic) { return topic * 0; })
				.vow.it.should.eql(0)
				
.suite();

if (module.parent) {
	suite["export"](module);
} else {
	suite.run({
		reporter: is.reporter
	}, function() {
		is.end();	
	});
}
